0.0.13
------

* Bug fix: Column measurement wasn't including header/footer rows.

0.0.12
------

* Replaced <bericht-col> with multi-pass column measurement.

0.0.11
------

* Bug fix: Measuring column width with <bericht-col> includes padding now.

0.0.10
------

* Bug fix: Cell properly renders multiple paragraphs.

0.0.9
-----

* Ignore letterhead-page style setting if no letterhead is available.

0.0.8
-----

* CSS supports mm, cm and inch dimensions.

0.0.7
-----

* Proper handling of XObject Resources in letterheads.

0.0.6
-----

* Proper handling of /DescendantFonts when creating letterhead XObject.

0.0.5
-----

* Template bug fix related to compression.

0.0.4
-----

* Added page-break-before CSS property.

0.0.3
-----

* Added missing dependencies.

0.0.2
-----

* Bug fixes and improvements.

0.0.1
-----

* Initial release.
